% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/as_qapply.R
\name{as_qapply}
\alias{as_qapply}
\title{Emulate a qapply call using lapply}
\usage{
as_qapply(X, FUN, fargs = NULL, commonData = NULL, workDir = getwd(),
  nCores = NULL, global = FALSE, all.names = FALSE, nPerPacket = NULL,
  tag = deparse(substitute(X)), internalize = TRUE, clearWd = TRUE,
  parSeed = NULL)
}
\arguments{
\item{X}{An array or list of values to be evaluated by \code{FUN}}

\item{FUN}{A function to be applied to \code{X}}

\item{fargs}{A list of (named) arguments for \code{FUN}}

\item{commonData}{A list of (named) objects that will be visible to each child
process.  Providing a non NULL value of this argument overrides global=TRUE.}

\item{workDir}{Where the worker processes will be spawned, and where the "out",
"err", and "log" temporary files will be created}

\item{nCores}{The number of computational cores to be used for the \code{length(X)} individual
jobs.  When \code{nPerPacket} is unspecified, \code{qapply} will
build \code{nCores} packets of jobs to reduce overhead tied to configuring the worker processes.
The default value of \code{nCores} is to take the number available to the grid at the
time of \code{qapply}'s execution.}

\item{global}{Pass the entire global environment (TRUE) to slave processes?  FALSE
by default as it's easy to flood system resources with large global
environments.}

\item{all.names}{When using global=TRUE, set all.names=TRUE if there are hidden
objects (i.e., objects beginning with ".") to be passed.}

\item{nPerPacket}{A vector of integers whose sum is \code{length(X)}.  Packet \code{i}
contains \code{nPerPacket[i]} elements of \code{X}.}

\item{tag}{A label for the job and temporary files related to the job.  The
default is to take the name of \code{X}.}

\item{internalize}{When TRUE, \code{qapply} will return a list containing the output of
\code{FUN} for each element of \code{X}.  When FALSE, \code{qapply}
acts simply to facilitate submission of jobs to the queue.  See \code{qsub}.}

\item{parSeed}{A vector of six integers which is passed to the \code{rlecuyer}
package for generating parallel random number streams.  If left blank,
the default is \code{rep(1111, 6)}.  See \code{qseed}}
}
\description{
Emulate a qapply call using lapply
}
\examples{

myfun <- function(i) sqrt(i) + A + B

X <- c(1,2,3)

com <- list(A = 1)

B <- 2

as_qapply(X, myfun, commonData = com)

as_qapply(X, myfun, tag = "demo", commonData = com, 
          internalize = FALSE, workDir = tempdir())

qinternalize(file.path(tempdir(), "out", "demo"))
}
